import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
  scaleOrdinal,
  schemeCategory10
} from 'd3';

import { dropDownMenu } from './dropDownMenu';
import { scatterPlot } from './scatterPlot';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const margin = { top: 20, right: 35, bottom: 100, left: 52 };

let data;
let xColumn;
let yColumn;
let selectedLegend;


const onXColumnClicked = column => {
  xColumn = column;  
  render();
};

const onYColumnClicked = column => {
  yColumn = column;  
  render();
};

const onClick = d => {
  selectedLegend = d;
//  console.log({selectedLegend});
  render();
};

const scatterG = svg.append('g')
  .attr('transform', `translate(${margin.left},${margin.top})`);

const render = () => {
  
  const cValue = data => data['Indicator_desc'];
  const color = scaleOrdinal();
  
  color
    .domain(data.map(cValue))
    .domain(color.domain().sort().reverse())
    .range(schemeCategory10);
  
  select('#x-menu')
    .call(dropDownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
  });
  
  select('#y-menu')
    .call(dropDownMenu, {
      options: data.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
  });
  
  scatterG.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    circleRadius: 4,
    yAxisLabel: yColumn,
    margin: margin,
    width,
    height,
    data,
    color,
    cValue,
    selectedLegend
  });
  
  svg.call(colorLegend, {
    color,
    width,
    onClick,
    selectedLegend
  });
  


};

csv('https://vizhub.com/veagy/datasets/2000-2016 Worldwide Exports.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d['China'] = +d['China'];
      d['United States of America'] = +d['United States of America'];
      d['Brazil'] = +d['Brazil'];
      d['India'] = +d['India'];
      d['Japan'] = +d['Japan'];
      d['Mexico'] = +d['Mexico'];
      d['Russian Federation'] = +d['Russian Federation'];
    });
    xColumn = data.columns[4];
    yColumn = data.columns[3];
    render();
});

